from setuptools import setup

setup(name = "js_distributions",
      version ="1.0",
      description = "Gaussian and Binomial distribution",
      package = ["js_distributions"],
      author_email ="jitedrasjeena8@gmail.com",
      zip_safe = False)